@@ -35,16 +35,15 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-pref("general.useragent.extra.thunderbird", "Thunderbird/1.0+");
-//@line 39 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+pref("general.useragent.extra.thunderbird", "Thunderbird/1.5.0.5");
+//@line 39 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 
 pref("general.useragent.locale", "en-US");
-//@line 41 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 41 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 pref("general.skins.selectedSkin", "classic/1.0");
 
-//@line 47 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 47 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 
-pref("app.extensions.version", "1.0+");
 pref("update.app.enabled", true); // Whether or not app updates are enabled 
 pref("update.app.url", "chrome://mozapps/locale/update/update.properties");	
 pref("update.extensions.enabled", true);
@@ -52,7 +51,7 @@ pref("update.extensions.enabled", true);
 // App-specific update preferences
 
 // Whether or not app updates are enabled
-pref("app.update.enabled", false);               
+pref("app.update.enabled", true);               
 
 // This preference turns on app.update.mode and allows automatic download and
 // install to take place. We use a separate boolean toggle for this to make     
@@ -71,16 +70,19 @@ pref("app.update.auto", true);
 pref("app.update.mode", 1);
 // If set to true, the Update Service will present no UI for any event.
 pref("app.update.silent", false);
-pref("app.update.logEnabled", true);
 
-// Default service URL for testing.
-pref("app.update.url", "chrome://mozapps/locale/update/updates.properties");
+// Update service URL:
+pref("app.update.url", "https://aus2.mozilla.org/update/1/%PRODUCT%/%VERSION%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/update.xml");
+pref("app.update.vendorName.override", "Mozilla");
+
 // URL user can browse to manually if for some reason all update installation
-// attempts fail.
-pref("app.update.url.manual", "chrome://mozapps/locale/update/updates.properties");
-// User-settable update preference that overrides app.update.url for testing 
-// purposes.
-pref("app.update.url.override", "chrome://mozapps/locale/update/updates.properties");
+// attempts fail.  TODO: Change this URL
+pref("app.update.url.manual", "http://www.mozilla.org/products/thunderbird/");
+// A default value for the "More information about this update" link
+// supplied in the "An update is available" page of the update wizard. 
+pref("app.update.url.details", "chrome://messenger-region/locale/region.properties");
+// User-settable override to app.update.url for testing purposes.
+//pref("app.update.url.override", "");
 
 // Interval: Time between checks for a new version (in seconds)
 //           default=1 day
@@ -93,7 +95,7 @@ pref("app.update.nagTimer.download", 86400);
 pref("app.update.nagTimer.restart", 1800);
 // Interval: When all registered timers should be checked (in milliseconds)
 //           default=5 seconds
-pref("app.update.timer", 5000);
+pref("app.update.timer", 600000);
 
 // Whether or not we show a dialog box informing the user that the update was
 // successfully applied. This is off in Firefox by default since we show a 
@@ -123,10 +125,8 @@ pref("extensions.update.autoUpdate", false);    // Automatically download and in
                                                 // updates to themes and extensions. 
                                                 // Does nothing at present. 
 
-pref("extensions.update.interval", 604800000);  // Check for updates to Extensions and 
-                                                // Themes every week
-pref("extensions.update.lastUpdateDate", 0);    // UTC offset when last Extension/Theme 
-                                                // update was performed. 
+pref("extensions.update.interval", 86400);  // Check for updates to Extensions and 
+                                            // Themes every week
 // Non-symmetric (not shared by extensions) extension-specific [update] preferences
 pref("extensions.getMoreExtensionsURL", "chrome://mozapps/locale/extensions/extensions.properties");
 pref("extensions.getMoreThemesURL", "chrome://mozapps/locale/extensions/extensions.properties");
@@ -160,11 +160,11 @@ pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
 pref("mail.phishing.detection.enabled", true); // enable / disable phishing detection for link clicks
 pref("mail.spellcheck.inline", true);
 
-//@line 167 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 167 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.instantApply", true);
-//@line 172 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 172 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 174 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 174 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 
 /////////////////////////////////////////////////////////////////
 // Overrides of the seamonkey suite mailnews.js prefs
@@ -172,11 +172,25 @@ pref("browser.preferences.animateFadeIn", false);
 pref("mail.showFolderPaneColumns", false); // setting to true will allow total/unread/size columns
 pref("mail.showCondensedAddresses", true); // show the friendly display name for people I know
 
+/////////////////////////////////////////////////////////////////
+// Privacy Controls for Handling Remote Content
+///////////////////////////////////////////////////////////////// 
 pref("mailnews.message_display.allow.plugins", false); // disable plugins by default
 pref("mailnews.message_display.disable_remote_image", true);
 pref("mailnews.message_display.disable_remote_images.useWhitelist", true);
 pref("mailnews.message_display.disable_remote_images.whiteListAbURI","moz-abmdbdirectory://abook.mab");
 
+/////////////////////////////////////////////////////////////////
+// Trusted Mail Domains
+//
+// Specific domains can be white listed to bypass various privacy controls in Thunderbird
+// such as blocking remote images, the phishing detector, etc. This is particularly
+// useful for business deployments where images or links reference servers inside a 
+// corporate intranet. For multiple domains, separate them with a comma. i.e.
+// pref("mail.trusteddomains", "mozilla.org,mozillafoundation.org");
+///////////////////////////////////////////////////////////////// 
+pref("mail.trusteddomains", "");
+
 // hidden pref for changing how we present attachments in the message pane
 pref("mailnews.attachments.display.largeView", false); 
 pref("mail.pane_config.dynamic",            0);
@@ -190,12 +204,6 @@ pref("mailnews.headers.minNumHeaders", 0); // 0 means we ignore this pref
 
 pref("mail.compose.dontWarnMail2Newsgroup", false);
 
-pref("messenger.throbber.url","chrome://messenger-region/locale/region.properties");
-pref("mailnews.release_notes.url","chrome://messenger-region/locale/region.properties");
-pref("mailnews.hints_and_tips.url","chrome://messenger-region/locale/region.properties");
-pref("compose.throbber.url","chrome://messenger-region/locale/region.properties");
-pref("addressbook.throbber.url","chrome://messenger-region/locale/region.properties");
-
 pref("network.image.imageBehavior", 2);
 pref("network.cookie.cookieBehavior", 3); // 0-Accept, 1-dontAcceptForeign, 2-dontUse, 3-p3p
 
@@ -203,12 +211,11 @@ pref("network.cookie.cookieBehavior", 3); // 0-Accept, 1-dontAcceptForeign, 2-do
 // End seamonkey suite mailnews.js pref overrides
 ///////////////////////////////////////////////////////////////// 
 
-//@line 213 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
-// whether to check if we're the default mail client on startup (GNOME)
+// whether to check if we are the default mail, news or feed client
+// on startup. 
 pref("mail.checkDefaultMail", true);
-// whether to check if we're the default news client on startup (GNOME)
 pref("mail.checkDefaultNews", false);
-//@line 218 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+pref("mail.checkDefaultFeed", false);
 
 /////////////////////////////////////////////////////////////////
 // Overrides for generic app behavior from the seamonkey suite's all.js
@@ -231,6 +238,7 @@ pref("intl.charset.detector", "chrome://global/locale/intl.properties");
 pref("intl.charset.default",  "chrome://global-platform/locale/intl.properties");
 pref("font.language.group", "chrome://global/locale/intl.properties");
 pref("intl.menuitems.alwaysappendaccesskeys","chrome://global/locale/intl.properties");
+pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/intl.properties");
 
 pref("signon.rememberSignons",              true);
 pref("signon.expireMasterPassword",         false);
@@ -271,6 +279,11 @@ pref("network.protocol-handler.warn-external.ftp", false);
 pref("network.hosts.smtp_server",           "mail");
 pref("network.hosts.pop_server",            "mail");
 
+pref("security.warn_entering_secure.show_once", false);
+pref("security.warn_entering_weak.show_once", false);
+pref("security.warn_leaving_secure.show_once", false);
+pref("security.warn_viewing_mixed.show_once", false);
+
 pref("general.config.obscure_value", 0); // for MCD .cfg files
 
 pref("xpinstall.dialog.confirm", "chrome://mozapps/content/xpinstall/xpinstallConfirm.xul");
@@ -421,11 +434,11 @@ pref("privacy.popups.sound_enabled",              true);
 pref("privacy.popups.sound_url",                  "");
 pref("privacy.popups.statusbar_icon_enabled",     true);
 
-//@line 432 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 445 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 // For the download dialog
 pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", false);
 pref("browser.urlbar.clickSelectsAll", false);
-//@line 437 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 450 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 
 // prevent status-bar spoofing even if people are foolish enough to turn on JS
 pref("dom.disable_window_status_change",          true);
