@@ -275,37 +275,45 @@ pref("ldap_2.servers.history.dirType",							2);
 pref("ldap_2.servers.history.isOffline",						false);
 
 // default mapping of addressbook properties to ldap attributes
-pref("ldap_2.servers.default.attrmap.FirstName", "givenname");
+pref("ldap_2.servers.default.attrmap.FirstName", "givenName");
 pref("ldap_2.servers.default.attrmap.LastName", "sn,surname");
-pref("ldap_2.servers.default.attrmap.DisplayName", "displayname,cn,commonname");
-pref("ldap_2.servers.default.attrmap.NickName", "xmozillanickname");
+pref("ldap_2.servers.default.attrmap.DisplayName", "cn,commonname");
+pref("ldap_2.servers.default.attrmap.NickName", "mozillaNickname,xmozillanickname");
 pref("ldap_2.servers.default.attrmap.PrimaryEmail", "mail");
-pref("ldap_2.servers.default.attrmap.SecondEmail", "xmozillasecondemail");
-pref("ldap_2.servers.default.attrmap.WorkPhone", "telephonenumber");
-pref("ldap_2.servers.default.attrmap.HomePhone", "homephone");
+pref("ldap_2.servers.default.attrmap.SecondEmail", "mozillaSecondEmail,xmozillasecondemail");
+pref("ldap_2.servers.default.attrmap.WorkPhone", "telephoneNumber");
+pref("ldap_2.servers.default.attrmap.HomePhone", "homePhone");
 pref("ldap_2.servers.default.attrmap.FaxNumber", "fax,facsimiletelephonenumber");
 pref("ldap_2.servers.default.attrmap.PagerNumber", "pager,pagerphone");
 pref("ldap_2.servers.default.attrmap.CellularNumber", "mobile,cellphone,carphone");
-pref("ldap_2.servers.default.attrmap.WorkAddress", "streetaddress,postofficebox");
+pref("ldap_2.servers.default.attrmap.WorkAddress", "street,streetaddress,postOfficeBox");
+pref("ldap_2.servers.default.attrmap.HomeAddress", "mozillaHomeStreet");
+pref("ldap_2.servers.default.attrmap.WorkAddress2", "mozillaWorkStreet2");
+pref("ldap_2.servers.default.attrmap.HomeAddress2", "mozillaHomeStreet2");
 pref("ldap_2.servers.default.attrmap.WorkCity", "l,locality");
+pref("ldap_2.servers.default.attrmap.HomeCity", "mozillaHomeLocalityName");
 pref("ldap_2.servers.default.attrmap.WorkState", "st,region");
-pref("ldap_2.servers.default.attrmap.WorkZipCode", "zip,postalcode");
-pref("ldap_2.servers.default.attrmap.WorkCountry", "countryname");
+pref("ldap_2.servers.default.attrmap.HomeState", "mozillaHomeState");
+pref("ldap_2.servers.default.attrmap.WorkZipCode", "postalCode,zip");
+pref("ldap_2.servers.default.attrmap.HomeZipCode", "mozillaHomePostalCode");
+pref("ldap_2.servers.default.attrmap.WorkCountry", "c,countryname");
+pref("ldap_2.servers.default.attrmap.HomeCountry", "mozillaHomeCountryName");
 pref("ldap_2.servers.default.attrmap.JobTitle", "title");
 pref("ldap_2.servers.default.attrmap.Department", "department,departmentnumber,ou,orgunit");
 pref("ldap_2.servers.default.attrmap.Company", "company,o");
-pref("ldap_2.servers.default.attrmap._AimScreenName", "nscpaimscreenname");
-pref("ldap_2.servers.default.attrmap.WebPage1", "workurl");
-pref("ldap_2.servers.default.attrmap.WebPage2", "homeurl");
+pref("ldap_2.servers.default.attrmap._AimScreenName", "nsAIMid,nscpaimscreenname");
+pref("ldap_2.servers.default.attrmap.WebPage1", "mozillaWorkUrl,workurl");
+pref("ldap_2.servers.default.attrmap.WebPage2", "mozillaHomeUrl,homeurl");
 pref("ldap_2.servers.default.attrmap.BirthYear", "birthyear");
-pref("ldap_2.servers.default.attrmap.Custom1", "custom1");
-pref("ldap_2.servers.default.attrmap.Custom2", "custom2");
-pref("ldap_2.servers.default.attrmap.Custom3", "custom3");
-pref("ldap_2.servers.default.attrmap.Custom4", "custom4");
-pref("ldap_2.servers.default.attrmap.Notes", "notes,description");
-pref("ldap_2.servers.default.attrmap.PreferMailFormat", "xmozillausehtmlmail");
+pref("ldap_2.servers.default.attrmap.Custom1", "mozillaCustom1,custom1");
+pref("ldap_2.servers.default.attrmap.Custom2", "mozillaCustom2,custom2");
+pref("ldap_2.servers.default.attrmap.Custom3", "mozillaCustom3,custom3");
+pref("ldap_2.servers.default.attrmap.Custom4", "mozillaCustom4,custom4");
+pref("ldap_2.servers.default.attrmap.Notes", "description,notes");
+pref("ldap_2.servers.default.attrmap.PreferMailFormat", "mozillaUseHtmlMail,xmozillausehtmlmail");
 pref("ldap_2.servers.default.attrmap.LastModifiedDate", "modifytimestamp");
 
+
 // A position of zero is a special value that indicates the directory is deleted.
 // These entries are provided to keep the (obsolete) Four11 directory and the
 // WhoWhere, Bigfoot and Switchboard directories from being migrated.
@@ -421,6 +429,11 @@ pref("mail.server.default.max_articles", 500);
 pref("mail.server.default.notify.on", true);
 pref("mail.server.default.mark_old_read", false);
 pref("mail.server.default.empty_trash_on_exit", false);
+// 0 = Keep Dupes, leave them alone
+// 1 = delete dupes
+// 2 = Move Dupes to trash
+// 3 = Mark Dupes as Read
+pref("mail.server.default.dup_action", 0);
 
 pref("mail.server.default.using_subscription", true);
 pref("mail.server.default.dual_use_folders", true);
@@ -510,6 +523,7 @@ pref("news.cancel.confirm",true);
 pref("news.cancel.alert_on_success",true);
 pref("mail.SpellCheckBeforeSend",false);
 pref("mail.spellcheck.inline",true);
+pref("mail.phishing.detection.enabled", true); // enable / disable phishing detection for link clicks
 pref("mail.warn_on_send_accel_key", true);
 pref("mail.enable_autocomplete",true);
 pref("mailnews.html_domains","");
@@ -613,7 +627,7 @@ pref("mailnews.fakeaccount.server", "");
 
 // message display properties
 pref("mailnews.message_display.disable_remote_image", false);
-pref("mailnews.message_display.allow.plugins", true);
+pref("mailnews.message_display.allow.plugins", false);
 
 // default msg compose font prefs
 pref("msgcompose.font_face",                "");
@@ -645,11 +659,9 @@ pref("mail.standalone", false);
 // the users last used preference.
 pref("mailnews.import.text.skipfirstrecord", true);
 
-//@line 653 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mailnews/mailnews.js"
+//@line 669 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mailnews/mailnews.js"
 
-//@line 661 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mailnews/mailnews.js"
-
-//@line 664 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mailnews/mailnews.js"
+//@line 672 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mailnews/mailnews.js"
 pref("mail.empty_trash", false);
 
 pref("mail.check_new_mail", true);
@@ -666,7 +678,5 @@ pref("news.show_first_unread", false);
 pref("news.sash_geometry", "");
 pref("mail.signature_date", 0);
 
-// until bug #130581 is fixed, we need to override this on linux
-pref("mail.compose.max_recycled_windows", 0);
-//@line 685 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mailnews/mailnews.js"
+//@line 691 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mailnews/mailnews.js"
 
