@@ -1,14 +1,21 @@
-//@line 40 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 40 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+
 
 /**
- * Determine whether or not a given focused DOMWindow is in the content
- * area.
- **/
- 
-function openNewTabWith(href, linkNode, event, securityCheck, postData, sendReferrer)
+ * openNewTabWith: opens a new tab with the given URL.
+ *
+ * @param href The URL to open (as a string).
+ * @param sourceURL The URL of the document from which the URL came, or null.
+ *          This is used to set the referrer header and to do a security check of whether
+ *          the document as allowed to reference the URL.
+ *          If null, there will be no referrer header and no security check.
+ * @param postData Form POST data, or null.
+ * @param event The triggering event (for the purpose of determining whether to open in the background), or null
+ */ 
+function openNewTabWith(href, sourceURL, postData, event)
 {
-  if (securityCheck)
-    urlSecurityCheck(href, document); 
+  if (sourceURL)
+    urlSecurityCheck(href, sourceURL);
 
   var prefSvc = Components.classes["@mozilla.org/preferences-service;1"]
                           .getService(Components.interfaces.nsIPrefService);
@@ -35,21 +42,15 @@ function openNewTabWith(href, linkNode, event, securityCheck, postData, sendRefe
   // open link in new tab
   var browser = top.document.getElementById("content");
 
-  // If sendReferrer is not specified, default to true
-  var referrer = (sendReferrer == false) ? null : getReferrer(document);
+  var referrerURI = sourceURL ? makeURI(sourceURL) : null;
 
-  var theTab = browser.addTab(href, referrer, originCharset, postData);
-  if (!loadInBackground)
-    browser.selectedTab = theTab;
-  
-  if (linkNode)
-    markLinkVisited(href, linkNode);
+  browser.loadOneTab(href, referrerURI, originCharset, postData, loadInBackground);
 }
 
-function openNewWindowWith(href, linkNode, securityCheck, postData, sendReferrer)
+function openNewWindowWith(href, sourceURL, postData)
 {
-  if (securityCheck)
-    urlSecurityCheck(href, document);
+  if (sourceURL)
+    urlSecurityCheck(href, sourceURL);
 
   // if and only if the current window is a browser window and it has a document with a character
   // set, then extract the current charset menu setting from the current document and use it to
@@ -59,65 +60,41 @@ function openNewWindowWith(href, linkNode, securityCheck, postData, sendReferrer
   if (wintype == "navigator:browser")
     charsetArg = "charset=" + window.content.document.characterSet;
 
-  // If sendReferrer is not specified, default to true
-  var referrer = (sendReferrer == false) ? null : getReferrer(document);
+  var referrerURI = sourceURL ? makeURI(sourceURL) : null;
 
-  window.openDialog(getBrowserURL(), "_blank", "chrome,all,dialog=no", href, charsetArg, referrer, postData);
-  
-  if (linkNode)
-    markLinkVisited(href, linkNode);
+  window.openDialog(getBrowserURL(), "_blank", "chrome,all,dialog=no", href, charsetArg, referrerURI, postData);
 }
 
-function markLinkVisited(href, linkNode)
+/**
+ * urlSecurityCheck: JavaScript wrapper for CheckLoadURIStr.
+ * If |sourceURL| is not allowed to link to |url|, this function throws with an error message.
+ *
+ * @param url The URL a page has linked to.
+ * @param sourceURL The URL of the document from which the URL came.
+ * @param flags Flags to be passed to checkLoadURIStr. If undefined,
+ *              nsIScriptSecurityManager.STANDARD will be passed to checkLoadURIStr.
+ */
+function urlSecurityCheck(url, sourceURL, flags)
 {
-  var globalHistory = Components.classes["@mozilla.org/browser/global-history;2"]
-                                .getService(Components.interfaces.nsIGlobalHistory2);
-
-  var uri = makeURI(href);
-  if (!globalHistory.isVisited(uri)) {
-    globalHistory.addURI(uri, false, true, null);
-    var oldHref = linkNode.getAttribute("href");
-    if (typeof oldHref == "string") {
-      // Use setAttribute instead of direct assignment.
-      // (bug 217195, bug 187195)
-      linkNode.setAttribute("href", "");
-      linkNode.setAttribute("href", oldHref);
-    }
-    else {
-      // Converting to string implicitly would be a 
-      // minor security hole (similar to bug 202994).
-    }
-  }
-}
-
-function urlSecurityCheck(url, doc) 
-{
-  // URL Loading Security Check
-  var focusedWindow = doc.commandDispatcher.focusedWindow;
-  var sourceURL = getContentFrameURI(focusedWindow);
-
-  var sourceURI = makeURI(sourceURL);
-  var destURI = makeURI(url);
-
   const nsIScriptSecurityManager = Components.interfaces.nsIScriptSecurityManager;
   var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                          .getService(nsIScriptSecurityManager);
+  if (flags === undefined)
+    flags = nsIScriptSecurityManager.STANDARD;
+
   try {
-    secMan.checkLoadURI(sourceURI, destURI, nsIScriptSecurityManager.STANDARD);
+    secMan.checkLoadURIStr(sourceURL, url, flags);
   } catch (e) {
-    throw "Load of " + url + " denied.";
+    throw "Load of " + url + " from " + sourceURL + " denied.";
   }
 }
 
 function webPanelSecurityCheck(aSourceURL, aDestURL) {
-  var sourceURI = makeURI(aSourceURL);
-  var destURI = makeURI(aDestURL);
-
   const nsIScriptSecurityManager = Components.interfaces.nsIScriptSecurityManager;
   var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                          .getService(nsIScriptSecurityManager);
   try {
-    secMan.checkLoadURI(sourceURI, destURI, nsIScriptSecurityManager.STANDARD);
+    secMan.checkLoadURIStr(aSourceURL, aDestURL, nsIScriptSecurityManager.STANDARD);
   } catch (e) {
     return false;
   }
@@ -129,34 +106,9 @@ function isContentFrame(aFocusedWindow)
   if (!aFocusedWindow)
     return false;
 
-  var focusedTop = Components.lookupMethod(aFocusedWindow, 'top')
-                             .call(aFocusedWindow);
-
-  return (focusedTop == window.content);
+  return (aFocusedWindow.top == window.content);
 }
 
-function getContentFrameURI(aFocusedWindow)
-{
-  var contentFrame = isContentFrame(aFocusedWindow) ? aFocusedWindow : window.content;
-  if (contentFrame)
-    return Components.lookupMethod(contentFrame, 'location').call(contentFrame).href;
-  else
-    return null;
-}
-
-function getReferrer(doc)
-{
-  var focusedWindow = doc.commandDispatcher.focusedWindow;
-  var sourceURL = getContentFrameURI(focusedWindow);
-
-  if (sourceURL) {
-    try {
-      return makeURI(sourceURL);
-    }
-    catch (e) { }
-  }
-  return null;
-}
 
 const kSaveAsType_Complete = 0;   // Save document with attached objects
 // const kSaveAsType_URL = 1;     // Save document or URL by itself
@@ -291,7 +243,13 @@ function internalSave(aURL, aDocument, aDefaultFileName, aContentDisposition,
   if (aChosenData)
     file = aChosenData.file;
   else {
-    initFileInfo(fileInfo, aURL, aDocument, aContentType, aContentDisposition);
+    var charset = null;
+    if (aDocument)
+      charset = aDocument.characterSet;
+    else if (aReferrer)
+      charset = aReferrer.originCharset;
+    initFileInfo(fileInfo, aURL, aDocument, aContentType, aContentDisposition,
+                 charset);
     var fpParams = {
       fpTitleKey: aFilePickerTitleKey,
       isDocument: isDocument,
@@ -436,14 +394,17 @@ function FileInfo(aSuggestedFileName, aFileName, aFileBaseName, aFileExt, aUri)
  *        determined by the caller.
  * @param aContentDisposition The content-disposition header for the object
  *        we're saving, if it could be determined by the caller.
+ * @param aURLCharset The charset of aURL.
  */
-function initFileInfo(aFI, aURL, aDocument, aContentType, aContentDisposition)
+function initFileInfo(aFI, aURL, aDocument, aContentType, aContentDisposition,
+                      aURLCharset)
 {
-  var docCharset = (aDocument ? aDocument.characterSet : null);
+  if (!aURLCharset && aDocument && aDocument.characterSet)
+    aURLCharset = aDocument.characterSet;
   try {
     // Get an nsIURI object from aURL if possible:
     try {
-      aFI.uri = makeURI(aURL, docCharset);
+      aFI.uri = makeURI(aURL, aURLCharset);
       // Assuming nsiUri is valid, calling QueryInterface(...) on it will
       // populate extra object fields (eg filename and file extension).
       var url = aFI.uri.QueryInterface(Components.interfaces.nsIURL);
@@ -498,9 +459,9 @@ function getTargetFile(aFpP, aSkipPrompt)
     if (aFolderType != "Downloads")
       throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
     
-//@line 545 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 506 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/toolkit/content/contentAreaUtils.js"
     return "Home";
-//@line 548 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 509 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/toolkit/content/contentAreaUtils.js"
   }
   
   function getDownloadsFolder(aFolder)
@@ -735,11 +696,11 @@ function makeWebBrowserPersist()
   return Components.classes[persistContractID].createInstance(persistIID);
 }
 
-function makeURI(aURL, aOriginCharset)
+function makeURI(aURL, aOriginCharset, aBaseURI)
 {
   var ioService = Components.classes["@mozilla.org/network/io-service;1"]
                             .getService(Components.interfaces.nsIIOService);
-  return ioService.newURI(aURL, aOriginCharset, null);
+  return ioService.newURI(aURL, aOriginCharset, aBaseURI);
 }
 
 function makeFileURI(aFile)
@@ -887,14 +848,12 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
 {
   if (!aDefaultExtension)
     return aFile;
-  
+
+//@line 900 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+      
   // Fix up the file name we're saving to to include the default extension
-  const stdURLContractID = "@mozilla.org/network/standard-url;1";
-  const stdURLIID = Components.interfaces.nsIURL;
-  var url = Components.classes[stdURLContractID].createInstance(stdURLIID);
-  url.filePath = aFile;
-  
-  if (url.fileExtension != aDefaultExtension)
+  var i = aFile.lastIndexOf(".");
+  if (aFile.substr(i + 1) != aDefaultExtension)
     return aFile + "." + aDefaultExtension;
 
   return aFile;
