@@ -1,4 +1,4 @@
-//@line 41 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/components/addrbook/content/addressbook.js"
+//@line 41 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/components/addrbook/content/addressbook.js"
 
 var cvPrefs = 0;
 var addressbook = 0;
@@ -175,8 +175,8 @@ function delayedOnLoadAddressBook()
   // interested in mailing list changes and not cards but we have to have both.
   addrbookSession.addAddressBookListener(
     gAddressBookAbListener,
-    Components.interfaces.nsIAbListener.directoryRemoved |
-    Components.interfaces.nsIAbListener.directoryItemRemoved);
+    Components.interfaces.nsIAddrBookSession.directoryRemoved |
+    Components.interfaces.nsIAddrBookSession.directoryItemRemoved);
 
   var dirTree = GetDirTree();
   dirTree.addEventListener("click",DirPaneClick,true);
@@ -567,11 +567,46 @@ function AbDeleteDirectory()
   parentArray.AppendElement(parentDir);
     
   var directory = GetDirectoryFromURI(selectedABURI);
-  var confirmDeleteMessage = gAddressBookBundle.getString(directory.isMailList ? "confirmDeleteMailingList" : "confirmDeleteAddressbook");
+  var confirmDeleteMessage;
+  var clearPrefsRequired = false;
 
-  if (!promptService.confirm(window, null, confirmDeleteMessage))
+  if (directory.isMailList)
+    confirmDeleteMessage = gAddressBookBundle.getString("confirmDeleteMailingList");
+  else {
+    // Check if this address book is being used for collection
+    if (gPrefs.getCharPref("mail.collect_addressbook") == selectedABURI &&
+        (gPrefs.getBoolPref("mail.collect_email_address_outgoing") ||
+         gPrefs.getBoolPref("mail.collect_email_address_incoming") ||
+         gPrefs.getBoolPref("mail.collect_email_address_newsgroup"))) {
+      var brandShortName = document.getElementById("bundle_brand").getString("brandShortName");
+
+      confirmDeleteMessage = gAddressBookBundle.getFormattedString("confirmDeleteCollectionAddressbook", [brandShortName]);
+      clearPrefsRequired = true;
+    }
+    else {
+      confirmDeleteMessage = gAddressBookBundle.getString("confirmDeleteAddressbook");
+    }
+  }
+
+  if (!promptService.confirm(window,
+                             gAddressBookBundle.getString(
+                                                directory.isMailList ?
+                                                "confirmDeleteMailingListTitle" :
+                                                "confirmDeleteAddressbookTitle"),
+                             confirmDeleteMessage))
     return;
 
+  // First clear all the prefs if required
+  if (clearPrefsRequired) {
+    gPrefs.setBoolPref("mail.collect_email_address_outgoing", false);
+    gPrefs.setBoolPref("mail.collect_email_address_incoming", false);
+    gPrefs.setBoolPref("mail.collect_email_address_newsgroup", false);
+
+    // Also reset the displayed value so that we don't get a blank item in the
+    // prefs dialog if it gets enabled.
+    gPrefs.setCharPref("mail.collect_addressbook", kPersonalAddressbookURI);
+  }
+
   var resourceArray = Components.classes["@mozilla.org/supports-array;1"].createInstance(Components.interfaces.nsISupportsArray);
   var selectedABResource = GetDirectoryFromURI(selectedABURI).QueryInterface(Components.interfaces.nsIRDFResource);
   resourceArray.AppendElement(selectedABResource);
@@ -837,13 +872,3 @@ function AbIMSelected()
   LaunchUrl(url);
 }
 
-function loadThrobberUrl(urlPref)
-{
-    var url;
-    try {
-        url = gPrefs.getComplexValue(urlPref, Components.interfaces.nsIPrefLocalizedString).data;
-        var messenger = Components.classes["@mozilla.org/messenger;1"].createInstance();
-        messenger = messenger.QueryInterface(Components.interfaces.nsIMessenger);
-        messenger.launchExternalURL(url);  
-    } catch (ex) {}
-}
