@@ -1,4 +1,4 @@
-//@line 44 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailWindowOverlay.js"
+//@line 44 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailWindowOverlay.js"
 
 const MSG_FLAG_READ              = 0x000001;
 const MSG_FLAG_IMAP_DELETED      = 0x200000;
@@ -303,7 +303,7 @@ function viewRefreshCustomMailViews(aCurrentViewValue)
   for (i = 0; i < numItems; i++)
   {
     var newMenuItem = document.createElement("menuitem");
-    newMenuItem.setAttribute("label", mailViewList.getMailViewAt(i).mailViewName);
+    newMenuItem.setAttribute("label", mailViewList.getMailViewAt(i).prettyName);
     newMenuItem.setAttribute("userdefined", "true");
     var oncommandStr = "ViewMessagesBy('userdefinedview" + (kLastDefaultViewIndex + i) + "');";  
     newMenuItem.setAttribute("oncommand", oncommandStr);
@@ -716,14 +716,22 @@ function MsgGetMessagesForAllServers(defaultServer)
             var protocolinfo = Components.classes["@mozilla.org/messenger/protocol/info;1?type=" + currentServer.type].getService(Components.interfaces.nsIMsgProtocolInfo);
             if (protocolinfo.canLoginAtStartUp && currentServer.loginAtStartUp)
             {
-                 if (currentServer.type == "pop3" && currentServer.downloadOnBiff)
-                 {
-                   CoalesceGetMsgsForPop3ServersByDestFolder(currentServer, pop3DownloadServersArray, localFoldersToDownloadTo);
-                   pop3Server = currentServer.QueryInterface(Components.interfaces.nsIPop3IncomingServer);
-                 }
-                 else
-                 // Check to see if there are new messages on the server
-                   currentServer.PerformBiff(msgWindow);
+                if (defaultServer && defaultServer.equals(currentServer) && 
+                  !defaultServer.isDeferredTo &&
+                  defaultServer.rootFolder == defaultServer.rootMsgFolder)
+                {
+                    dump(currentServer.serverURI + "...skipping, already opened\n");
+                }
+                else if (currentServer.type == "pop3" && currentServer.downloadOnBiff)
+                {
+                    CoalesceGetMsgsForPop3ServersByDestFolder(currentServer, pop3DownloadServersArray, localFoldersToDownloadTo);
+                    pop3Server = currentServer.QueryInterface(Components.interfaces.nsIPop3IncomingServer);
+                }
+                else
+                {		 
+                    // Check to see if there are new messages on the server
+                    currentServer.PerformBiff(msgWindow);
+                }
             }
         }
         for (var i = 0; i < pop3DownloadServersArray.length; i++)
@@ -859,12 +867,17 @@ function MsgNewMessage(event)
 function MsgReplyMessage(event)
 {
   var loadedFolder = GetLoadedMsgFolder();
-  var server = loadedFolder.server;
+  if (loadedFolder)
+  {
+    var server = loadedFolder.server;
 
-  if(server && server.type == "nntp")
-    MsgReplyGroup(event);
-  else
-    MsgReplySender(event);
+    if(server && server.type == "nntp")
+    {
+      MsgReplyGroup(event);
+      return;
+    }
+  }
+  MsgReplySender(event);
 }
 
 function MsgReplySender(event)
@@ -894,10 +907,9 @@ function MsgReplyToAllMessage(event)
   var loadedFolder = GetLoadedMsgFolder();
   var messageArray = GetSelectedMessages();
 
-  if (event && event.shiftKey)
-    ComposeMessage(msgComposeType.ReplyAll, msgComposeFormat.OppositeOfDefault, loadedFolder, messageArray);
-  else
-    ComposeMessage(msgComposeType.ReplyAll, msgComposeFormat.Default, loadedFolder, messageArray);
+  ComposeMessage(msgComposeType.ReplyAll, 
+    (event && event.shiftKey) ? msgComposeFormat.OppositeOfDefault : msgComposeFormat.Default,
+    loadedFolder, messageArray);
 }
 
 function MsgForwardMessage(event)
@@ -1200,9 +1212,9 @@ function MsgOpenFromFile()
    }
 
    var uri = fp.fileURL;
-   uri.query = "type=x-message-display";
+   uri.query = "type=application/x-message-display";
 
-  MsgOpenNewWindowForMessage(uri, null);
+  window.openDialog( "chrome://messenger/content/messageWindow.xul", "_blank", "all,chrome,dialog=no,status,toolbar", uri, null, null );
 }
 
 function MsgOpenNewWindowForMessage(messageUri, folderUri)
@@ -1287,6 +1299,7 @@ function MsgDownloadSelected()
 
 function MsgMarkThreadAsRead()
 {
+  ClearPendingReadTimer();
   gDBView.doCommand(nsMsgViewCommandType.markThreadRead);
 }
 
@@ -2056,7 +2069,7 @@ function HandleJunkStatusChanged(folder)
   // this might be the stand alone window, open to a message that was
   // and attachment (or on disk), in which case, we want to ignore it.
   var loadedMessage = GetLoadedMessage();
-  if (loadedMessage && (!(/type=x-message-display/.test(loadedMessage))) && IsCurrentLoadedFolder(folder))
+  if (loadedMessage && (!(/type=application\/x-message-display/.test(loadedMessage))) && IsCurrentLoadedFolder(folder))
   {
     // if multiple message are selected
     // and we change the junk status
@@ -2117,7 +2130,9 @@ var gMessageNotificationBar =
       isJunk = ((junkScore != "") && (junkScore != "0"));
     }
 
-    this.updateMsgNotificationBar (isJunk ? kMsgNotificationJunkBar : kMsgNotificationNoStatus);
+    // phishing scams take precedence over junk
+    if (this.mMsgNotificationBar.selectedIndex != kMsgNotificationPhishingBar && isJunk)
+      this.updateMsgNotificationBar (kMsgNotificationJunkBar);
 
     goUpdateCommand('button_junk');
 
@@ -2126,9 +2141,8 @@ var gMessageNotificationBar =
 
   setRemoteContentMsg: function (aMsgHdr)
   {  
-    // The phishing message and junk message takes precedence over the remote content msg
-    if (this.mMsgNotificationBar.selectedIndex != kMsgNotificationJunkBar && 
-        this.mMsgNotificationBar.selectedIndex != kMsgNotificationPhishingBar)
+    // phishing and junk messages take precedence over the remote content msg...
+    if (this.mMsgNotificationBar.selectedIndex == kMsgNotificationNoStatus)
       this.updateMsgNotificationBar(aMsgHdr && aMsgHdr.getUint32Property("remoteContentPolicy") == kBlockRemoteContent ? 
                                     kMsgNotificationRemoteImages : kMsgNotificationNoStatus);
   },
@@ -2137,7 +2151,7 @@ var gMessageNotificationBar =
   setPhishingMsg: function(aUrl)
   {
     var msgURI = GetLoadedMessage();
-    if (msgURI && !(/type=x-message-display/.test(msgURI)))
+    if (msgURI && !(/type=application\/x-message-display/.test(msgURI)))
     {
       var msgHdr = messenger.messageServiceFromURI(msgURI).messageURIToMsgHdr(msgURI);
       // if we've explicitly marked this message as not being an email scam, then don't
@@ -2146,9 +2160,8 @@ var gMessageNotificationBar =
         return; 
     }
 
-    // The Junk message takes precedence over the phishing message...so skip this step
-    // if the message is already marked as junk
-    if (this.mMsgNotificationBar.selectedIndex != kMsgNotificationJunkBar && isMsgEmailScam(aUrl))
+    // phishing scams take precedence over junk and remote images.
+    if (isMsgEmailScam(aUrl))
       this.updateMsgNotificationBar(kMsgNotificationPhishingBar);
   },
 
@@ -2178,7 +2191,7 @@ function LoadMsgWithRemoteContent()
   var msgURI = GetLoadedMessage();
   var msgHdr = null;
     
-  if (msgURI && !(/type=x-message-display/.test(msgURI)))
+  if (msgURI && !(/type=application\/x-message-display/.test(msgURI)))
   {
     msgHdr = messenger.messageServiceFromURI(msgURI).messageURIToMsgHdr(msgURI);
     if (msgHdr)
@@ -2198,7 +2211,7 @@ function MsgIsNotAScam()
   var msgURI = GetLoadedMessage();
   var msgHdr = null;
     
-  if (msgURI && !(/type=x-message-display/.test(msgURI)))
+  if (msgURI && !(/type=application\/x-message-display/.test(msgURI)))
   {
     msgHdr = messenger.messageServiceFromURI(msgURI).messageURIToMsgHdr(msgURI);
     if (msgHdr)
@@ -2211,6 +2224,7 @@ function MsgIsNotAScam()
 
 function MarkCurrentMessageAsRead()
 {
+  ClearPendingReadTimer();
   gDBView.doCommand(nsMsgViewCommandType.markMessagesRead);
 }
 
@@ -2249,9 +2263,14 @@ function OnMsgLoaded(aUrl)
     // if the user clicks on another message then that message stays selected
     // and the selection does not "snap back" to the message chosen by
     // SetNextMessageAfterDelete() when the operation completes (bug 243532).
-    gNextMessageViewIndexAfterDelete = -2;
+    // But the just loaded message might be getting deleted, if the user
+    // deletes it before the message is loaded (bug 183394)
 
-    if (!(/type=x-message-display/.test(msgURI)))
+    var wintype = document.documentElement.getAttribute('windowtype');
+    if (wintype == "mail:messageWindow" || GetThreadTree().view.selection.currentIndex != gSelectedIndexWhenDeleting)
+      gNextMessageViewIndexAfterDelete = -2;
+
+    if (!(/type=application\/x-message-display/.test(msgURI)))
       msgHdr = messenger.messageServiceFromURI(msgURI).messageURIToMsgHdr(msgURI);
      
     gMessageNotificationBar.setJunkMsg(msgHdr);
@@ -2263,9 +2282,11 @@ function OnMsgLoaded(aUrl)
 
     if (msgHdr && !msgHdr.isRead)
     {
-      var wintype = document.firstChild.getAttribute('windowtype');
       if (markReadOnADelay && wintype == "mail:3pane") // only use the timer if viewing using the 3-pane preview pane and the user has set the pref
+      {
+        ClearPendingReadTimer();
         gMarkViewedMessageAsReadTimer = setTimeout(MarkCurrentMessageAsRead, gPrefBranch.getIntPref("mailnews.mark_message_read.delay.interval") * 1000);
+      }
       else
         MarkCurrentMessageAsRead();
     }
@@ -2310,7 +2331,7 @@ function OnMsgLoaded(aUrl)
 
         res = outputPFC.copyMessages(currentMsgFolder, messages, false /*isMove*/, msgWindow /* nsIMsgWindow */, null /* listener */, false /* isFolder */, false /*allowUndo*/ );
       }
-     }
+   }
 }
 
 //
@@ -2464,25 +2485,26 @@ function OpenOrFocusWindow(args, windowType, chromeURL)
     window.openDialog(chromeURL, "", "chrome,resizable,status,centerscreen,dialog=no", args);
 }
 
-
-function loadThrobberUrl(urlPref)
-{
-    var url;
-    try {
-        url = gPrefBranch.getComplexValue(urlPref, Components.interfaces.nsIPrefLocalizedString).data;
-        messenger.launchExternalURL(url);  
-    } catch (ex) {}
-}
-
 /**
  * Opens the update manager and checks for updates to the application.
  */
 
 function checkForUpdates()
 {
-  var prompter = Components.classes["@mozilla.org/updates/update-prompt;1"]
-                           .createInstance(Components.interfaces.nsIUpdatePrompt);
-  prompter.checkForUpdates(window);
+  var um = 
+      Components.classes["@mozilla.org/updates/update-manager;1"].
+      getService(Components.interfaces.nsIUpdateManager);
+  var prompter = 
+      Components.classes["@mozilla.org/updates/update-prompt;1"].
+      createInstance(Components.interfaces.nsIUpdatePrompt);
+
+  // If there's an update ready to be applied, show the "Update Downloaded"
+  // UI instead and let the user know they have to restart the application for
+  // the changes to be applied. 
+  if (um.activeUpdate && um.activeUpdate.state == "pending")
+    prompter.showUpdateDownloaded(um.activeUpdate);
+  else
+    prompter.checkForUpdates();
 }
 
 function buildHelpMenu()
@@ -2504,28 +2526,36 @@ function buildHelpMenu()
 
   if (!gMessengerBundle)
     gMessengerBundle = document.getElementById("bundle_messenger");
-  
-  var label = gMessengerBundle.getString("updates_checkForUpdates");
+
   var activeUpdate = um.activeUpdate;
-  if (activeUpdate) 
-  {
-    if (updates.isDownloading) 
-    {
-      if (activeUpdate.name) 
-        label = gMessengerBundle.getFormattedString("updates_downloadingUpdates", [activeUpdate.name]);
-      else
-        label = gMessengerBundle.getString("updates_downloadingUpdatesFallback");
-    }
-    else 
-    {
-      if (activeUpdate.name) 
-        label = gMessengerBundle.getFormattedString("updates_resumeDownloading", [activeUpdate.name]);
-      else
-        label = gMessengerBundle.getString("updates_resumeDownloadingFallback");
+  
+  // If there's an active update, substitute its name into the label
+  // we show for this item, otherwise display a generic label.
+  function getStringWithUpdateName(key) {
+    if (activeUpdate && activeUpdate.name)
+      return gMessengerBundle.getFormattedString(key, [activeUpdate.name]);
+    return gMessengerBundle.getString(key + "Fallback");
+  }
+  
+  // By default, show "Check for Updates..."
+  var key = "default";
+  if (activeUpdate) {
+    switch (activeUpdate.state) {
+    case "downloading":
+      // If we're downloading an update at present, show the text:
+      // "Downloading Firefox x.x..." otherwise we're paused, and show
+      // "Resume Downloading Firefox x.x..."
+      key = updates.isDownloading ? "downloading" : "resume";
+      break;
+    case "pending":
+      // If we're waiting for the user to restart, show: "Apply Downloaded
+      // Updates Now..."
+      key = "pending";
+      break;
     }
   }
 
-  checkForUpdates.label = label;
+  checkForUpdates.label = getStringWithUpdateName("updatesItem_" + key);
   if (um.activeUpdate && updates.isDownloading)
     checkForUpdates.setAttribute("loading", "true");
   else
