@@ -1,4 +1,4 @@
-//@line 37 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/downloadactions.js"
+//@line 37 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/downloadactions.js"
 
 const kRootTypePrefix = "urn:mimetype:";
 
@@ -212,13 +212,13 @@ var gDownloadActionsWindow = {
   
   _getDisplayNameForFile: function (aFile)
   {
-//@line 254 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/downloadactions.js"
+//@line 254 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/downloadactions.js"
     // XXXben - Read the bundle name on OS X.
     var ios = Components.classes["@mozilla.org/network/io-service;1"]
                         .getService(Components.interfaces.nsIIOService);
     var url = ios.newFileURI(aFile).QueryInterface(Components.interfaces.nsIURL);
     return url.fileName;
-//@line 260 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/downloadactions.js"
+//@line 260 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/downloadactions.js"
   },  
   
   _loadMIMERegistryData: function ()
@@ -259,6 +259,8 @@ var gDownloadActionsWindow = {
       catch (e) {
         customHandler = null;
       }      
+      if (customHandler && !customHandler.exists())
+        customHandler = null;
       var mimeType = this._getLiteralValue(type, "value");
       var typeInfo = this._mimeSvc.getFromTypeAndExtension(mimeType, null);
 
